==> aidlab_sdk-0.0.19.tar.gz: pigeons/aidlab.dart <==
// @dart=2.9

import 'package:pigeon/pigeon.dart';

import 'aidlab_delegate.dart';
import 'aidlab_internal.dart';

@HostApi()
abstract class PlatformAidlab {
  void disconnect();

  void send(SendRequest sendRequest);

  void setECGFiltrationMethod(EcgFiltrationRequest ecgFiltrationRequest);

  void startSynchronization();

  void stopSynchronization();

  void requestForFirmwareInfo(FirmwareInfoRequest firmwareInfoRequest);

  void startFirmwareUpdate(FirmwareUpdateRequest firmwareUpdateRequest);
}

class SendRequest {
  String command;
}

class EcgFiltrationRequest {
  int method;
}

class FirmwareInfoRequest {
  String url;
}

class FirmwareUpdateRequest {
  String url;
  String updatableVersion;
}

@FlutterApi()
abstract class PlatformAidlabSynchronizationDelegate {
  void syncStateDidChange(SyncStateEvent syncStateEvent);

  void didReceivePastECG(EcgEvent ecgEvent);

  void didReceivePastRespiration(RespirationEvent respirationEvent);

  void didReceivePastSkinTemperature(SkinTemperatureEvent skinTemperatureEvent);

  void didReceivePastHeartRate(HeartRateEvent heartRateEvent);

  void didReceivePastHrv(HrvEvent hrvEvent);

  void didReceiveUnsynchronizedSize(
      UnsynchronizedSizeEvent unsynchronizedSizeEvent);

  void didReceivePastRespirationRate(RespirationRateEvent respirationRateEvent);

  void didReceivePastActivity(ActivityEvent activityEvent);

  void didReceivePastSteps(StepsEvent stepsEvent);

  void didReceivePastSoundVolume(SoundVolumeEvent soundVolumeEvent);

  void didReceivePastAccelerometer(VectorEvent vectorEvent);

  void didReceivePastGyroscope(VectorEvent vectorEvent);

  void didReceivePastMagnetometer(VectorEvent vectorEvent);

  void didReceivePastQuaternion(QuaternionEvent quaternionEvent);

  void didReceivePastOrientation(OrientationEvent orientationEvent);

  void didReceivePastBodyPosition(BodyPositionEvent bodyPositionEvent);

  void didReceivePastPressure(PressureEvent pressureEvent);

  void didDetectPastUserEvent(UserEvent userEvent);

  void didReceivePastSoundFeatures(SoundFeaturesEvent soundFeaturesEvent);

  void didReceivePastSignalQuality(SignalQualityEvent signalQualityEvent);
}

class SyncStateEvent {
  int state;
}

class UnsynchronizedSizeEvent {
  int unsynchronizedSize;
  double syncBytesPerSecond;
}

==> aidlab_sdk-0.0.21.tar.gz: pigeons/aidlab.dart <==
// @dart=2.9

import 'package:pigeon/pigeon.dart';

import 'aidlab_delegate.dart';
import 'aidlab_internal.dart';

@HostApi()
abstract class PlatformAidlab {
  void disconnect();

  void send(SendRequest sendRequest);

  void setECGFiltrationMethod(EcgFiltrationRequest ecgFiltrationRequest);

  void startSynchronization();

  void stopSynchronization();

  void requestForFirmwareInfo(FirmwareInfoRequest firmwareInfoRequest);

  void startFirmwareUpdate(FirmwareUpdateRequest firmwareUpdateRequest);
}

class SendRequest {
  String command;
}

class EcgFiltrationRequest {
  int method;
}

class FirmwareInfoRequest {
  String url;
}

class FirmwareUpdateRequest {
  String url;
  String updatableVersion;
}

@FlutterApi()
abstract class PlatformAidlabSynchronizationDelegate {
  void syncStateDidChange(SyncStateEvent syncStateEvent);

  void didReceivePastECG(EcgEvent ecgEvent);

  void didReceivePastRespiration(RespirationEvent respirationEvent);

  void didReceivePastSkinTemperature(SkinTemperatureEvent skinTemperatureEvent);

  void didReceivePastHeartRate(HeartRateEvent heartRateEvent);

  void didReceivePastRr(RrEvent rrEvent);

  void didReceiveUnsynchronizedSize(
      UnsynchronizedSizeEvent unsynchronizedSizeEvent);

  void didReceivePastRespirationRate(RespirationRateEvent respirationRateEvent);

  void didReceivePastActivity(ActivityEvent activityEvent);

  void didReceivePastSteps(StepsEvent stepsEvent);

  void didReceivePastSoundVolume(SoundVolumeEvent soundVolumeEvent);

  void didReceivePastAccelerometer(VectorEvent vectorEvent);

  void didReceivePastGyroscope(VectorEvent vectorEvent);

  void didReceivePastMagnetometer(VectorEvent vectorEvent);

  void didReceivePastQuaternion(QuaternionEvent quaternionEvent);

  void didReceivePastOrientation(OrientationEvent orientationEvent);

  void didReceivePastBodyPosition(BodyPositionEvent bodyPositionEvent);

  void didReceivePastPressure(PressureEvent pressureEvent);

  void didDetectPastUserEvent(UserEvent userEvent);

  void didReceivePastSoundFeatures(SoundFeaturesEvent soundFeaturesEvent);

  void didReceivePastSignalQuality(SignalQualityEvent signalQualityEvent);
}

class SyncStateEvent {
  int state;
}

class UnsynchronizedSizeEvent {
  int unsynchronizedSize;
  double syncBytesPerSecond;
}
